==> lxqt-config_1.4.0.orig.tar.xz: lxqt-config-1.4.0/lxqt-config-brightness/translations/lxqt-config-brightness_gl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl">
<context>
    <name>BrightnessSettings</name>
    <message>
        <location filename="../brightnesssettings.ui" line="14"/>
        <source>Brightness Settings</source>
        <translation>Axustes do brillo</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="35"/>
        <location filename="../brightnesssettings.ui" line="74"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="42"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Configuración de retroiluminación e brillos:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="51"/>
        <source>Backlight</source>
        <translation>Retroiluminación</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="57"/>
        <source>☼</source>
        <translation type="unfinished">☼</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="87"/>
        <source>Brightness</source>
        <translation type="unfinished">Brillo</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="105"/>
        <source>Require confirmation after settings change</source>
        <translation>Esixir a confirmación despois da modificación dos axustes</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="112"/>
        <source>Brightness settings changed</source>
        <translation>Cambiou a configuración do brillo</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="113"/>
        <source>Confirmation required. Are the settings correct?</source>
        <translation>Requírese a confirmación. Son correctos os axustes?</translation>
    </message>
</context>
<context>
    <name>OutputWidget</name>
    <message>
        <location filename="../outputwidget.ui" line="38"/>
        <source>&lt;b&gt;Output:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Saída:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="48"/>
        <source>☼</source>
        <translation type="unfinished">☼</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="80"/>
        <source>☀</source>
        <translation type="unfinished">☀</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>Increase brightness.</source>
        <translation>Aumenta o brillo.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Decrease brightness.</source>
        <translation>Diminuír o brillo.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Set brightness from 1 to 100.</source>
        <translation>Establece o brillo de 1 a 100.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Reset gamma to default value.</source>
        <translation>Restablecer gamma ao valor predeterminado.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="112"/>
        <source>%1: Can&apos;t use increase/decrease and set in conjunction</source>
        <translation>%1: Non se pode usar aumentar/diminución e establecer conxuntamente</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="117"/>
        <source>%1: Can&apos;t use increase and decrease options in conjunction</source>
        <translation type="unfinished">%1: Non se pode usar aumentar/diminución e establecer conxuntamente</translation>
    </message>
</context>
</TS>

==> lxqt-config_2.1.1.orig.tar.xz: lxqt-config-2.1.1/lxqt-config-brightness/translations/lxqt-config-brightness_gl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl">
<context>
    <name>BrightnessSettings</name>
    <message>
        <location filename="../brightnesssettings.ui" line="14"/>
        <source>Brightness Settings</source>
        <translation>Axustes do brillo</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="35"/>
        <location filename="../brightnesssettings.ui" line="74"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="42"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Configuración de retroiluminación e brillos:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="51"/>
        <source>Backlight</source>
        <translation>Retroiluminación</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="57"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="87"/>
        <source>Brightness</source>
        <translation>Brillo</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="105"/>
        <source>Require confirmation after settings change</source>
        <translation>Esixir a confirmación despois da modificación dos axustes</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="112"/>
        <source>Brightness settings changed</source>
        <translation>Cambiou a configuración do brillo</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="113"/>
        <source>Confirmation required. Are the settings correct?</source>
        <translation>Requírese a confirmación. Son correctos os axustes?</translation>
    </message>
</context>
<context>
    <name>OutputWidget</name>
    <message>
        <location filename="../outputwidget.ui" line="38"/>
        <source>&lt;b&gt;Output:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Saída:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="48"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="80"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>Increase brightness.</source>
        <translation>Aumenta o brillo.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Decrease brightness.</source>
        <translation>Diminuír o brillo.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Set brightness from 1 to 100.</source>
        <translation>Establece o brillo de 1 a 100.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Reset gamma to default value.</source>
        <translation>Restablecer gamma ao valor predeterminado.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="112"/>
        <source>%1: Can&apos;t use increase/decrease and set in conjunction</source>
        <translation>%1: Non se pode usar aumentar/diminución e establecer conxuntamente</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="117"/>
        <source>%1: Can&apos;t use increase and decrease options in conjunction</source>
        <translation>%1: Non se pode usar aumentar/diminución e establecer conxuntamente</translation>
    </message>
</context>
</TS>
